Rdocumentation
powered by
Learn R Programming
addinexamples (version 0.1.0)
findAndReplaceAddin: Find and Replace Tokens in a Document
Description
Call this as an addin to replace occurrences of a particular sequence of characters in a document with a new sequence of characters.
Usage
findAndReplaceAddin()
Arguments